@@ -76,6 +76,22 @@ class TestAuth:
 		assert user
 		assert new_name == user['displayName']
 
+	def test_set_custom_user_claims(self, auth):
+		with pytest.raises(AttributeError) as exc_info:
+			auth.set_custom_user_claims(self.__class__.user.get('localId'), {'premium': True})
+			auth.set_custom_user_claims(self.__class__.anonymous_user.get('localId'), {'premium': True})
+
+		assert "'NoneType' object has no attribute 'valid'" in str(exc_info.value)
+
+	def test_verify_id_token(self, auth):
+		with pytest.raises(KeyError) as exc_info:
+			auth.verify_id_token(self.__class__.user.get('idToken'))['premium'] is True
+		assert "'premium'" in str(exc_info.value)
+
+		with pytest.raises(KeyError) as exc_info:
+			auth.verify_id_token(self.__class__.anonymous_user.get('idToken'))['premium'] is True
+		assert "'premium'" in str(exc_info.value)
+
 	def test_delete_user_account(self, auth):
 		assert auth.delete_user_account(self.__class__.user.get('idToken'))
 		assert auth.delete_user_account(self.__class__.anonymous_user.get('idToken'))
@@ -118,19 +134,16 @@ class TestAuthAdmin:
 		self.__class__.anonymous_user = user
 		assert user
 
-	@pytest.mark.xfail
 	def test_create_custom_token(self, auth_admin):
 		token = auth_admin.create_custom_token('CreateCustomToken1')
 		self.__class__.custom_token = token
 		assert token
 
-	@pytest.mark.xfail
 	def test_create_custom_token_with_claims(self, auth_admin):
 		token = auth_admin.create_custom_token('CreateCustomToken2', {'premium': True})
 		self.__class__.custom_token_with_claims = token
 		assert token
 
-	@pytest.mark.xfail
 	def test_sign_in_with_custom_token(self, auth_admin):
 		user1 = auth_admin.sign_in_with_custom_token(self.__class__.custom_token)
 		user2 = auth_admin.sign_in_with_custom_token(self.__class__.custom_token_with_claims)
@@ -141,9 +154,6 @@ class TestAuthAdmin:
 		assert user1
 		assert user2
 
-	def test_refresh(self, auth_admin):
-		assert auth_admin.refresh(self.__class__.user.get('refreshToken'))
-
 	def test_get_account_info(self, auth_admin):
 		assert auth_admin.get_account_info(self.__class__.user.get('idToken'))
 
@@ -163,11 +173,26 @@ class TestAuthAdmin:
 		assert user
 		assert new_name == user['displayName']
 
+	def test_set_custom_user_claims(self, auth_admin):
+		auth_admin.set_custom_user_claims(self.__class__.user.get('localId'), {'premium': True})
+		auth_admin.set_custom_user_claims(self.__class__.anonymous_user.get('localId'), {'premium': True})
+
+	def test_refresh(self, auth_admin):
+		self.__class__.user = auth_admin.refresh(self.__class__.user.get('refreshToken'))
+		self.__class__.custom_user = auth_admin.refresh(self.__class__.custom_user.get('refreshToken'))
+		self.__class__.anonymous_user = auth_admin.refresh(self.__class__.anonymous_user.get('refreshToken'))
+
+	def test_verify_id_token(self, auth_admin):
+		assert auth_admin.verify_id_token(self.__class__.user.get('idToken'))['premium'] is True
+		assert auth_admin.verify_id_token(self.__class__.anonymous_user.get('idToken'))['premium'] is True
+		assert auth_admin.verify_id_token(self.__class__.custom_user_with_claims.get('idToken'))['premium'] is True
+
+		with pytest.raises(KeyError) as exc_info:
+			auth_admin.verify_id_token(self.__class__.custom_user.get('idToken'))['premium'] is True
+		assert "'premium'" in str(exc_info.value)
+
 	def test_delete_user_account(self, auth_admin):
 		assert auth_admin.delete_user_account(self.__class__.user.get('idToken'))
 		assert auth_admin.delete_user_account(self.__class__.anonymous_user.get('idToken'))
-
-	@pytest.mark.xfail
-	def test_delete_custom_user_account(self, auth_admin):
 		assert auth_admin.delete_user_account(self.__class__.custom_user.get('idToken'))
 		assert auth_admin.delete_user_account(self.__class__.custom_user_with_claims.get('idToken'))
